@@ -45,13 +45,7 @@ from gnomemusic.grilo import grilo
 import gnomemusic.widgets as Widgets
 from gnomemusic.query import Query
 from gnomemusic.albumArtCache import AlbumArtCache as albumArtCache
-
-try:
-    tracker = Tracker.SparqlConnection.get(None)
-except Exception as e:
-    from sys import exit
-    print("Cannot connect to tracker, error '%s'\Exiting" % str(e))
-    exit(1)
+tracker = Tracker.SparqlConnection.get(None)
 
 if Gtk.get_minor_version() > 8:
     from gi.repository.Gtk import Stack, StackTransitionType
@@ -72,8 +66,8 @@ class ViewContainer(Stack):
     def __init__(self, title, header_bar, selection_toolbar, useStack=False):
         Stack.__init__(self,
                        transition_type=StackTransitionType.CROSSFADE)
-        self._grid = Gtk.Grid(orientation=Gtk.Orientation.HORIZONTAL)
-        self._iconWidth = 128
+        self._grid = Gtk.Grid(orientation=Gtk.Orientation.VERTICAL)
+        self._iconWidth = -1
         self._iconHeight = 128
         self._offset = 0
         self._adjustmentValueId = 0
@@ -96,6 +90,7 @@ class ViewContainer(Stack):
             shadow_type=Gtk.ShadowType.NONE
         )
         self.view.set_view_type(Gd.MainViewType.ICON)
+        self.view.set_model(self._model)
         self.filter = self._model.filter_new(None)
         self.view.set_model(self.filter)
         self.vadjustment = self.view.get_vadjustment()
@@ -275,7 +270,6 @@ class ViewContainer(Stack):
             self._model.set_value(
                 _iter, 4,
                 albumArtCache.get_default()._make_icon_frame(icon))
-            self.view.queue_draw()
 
     def _add_list_renderers(self):
         pass
